==> elixir-react-native-components-1.2.0.tgz: package/components/tdl/sms.js <==
import React, { Component } from "react";
import PropTypes from "prop-types";
import { ScrollView, View, Pressable, Text, Modal, StatusBar, BackHandler, Platform } from "react-native";
import { Icon, HStack, Left, Body, Title, Right, VStack, Divider } from "native-base";
import { Ionicons } from '@expo/vector-icons';
import RBSheet from "react-native-raw-bottom-sheet";
import { KeyboardAwareScrollView } from "react-native-keyboard-aware-scrollview";
import { Button, Pagination } from "@ant-design/react-native";
import * as Util from "../../helpers/util";
import Group from "../group/index";
import { SMSPagination, setCurrentObjectPath, executeAction, sendRefreshRequest, requestBack } from "../../redux/actions";
import { getTranslation } from "../../labels";
import { getTheme } from "../../styles/themes";
import store from "../../redux";
import * as colors from './../../src-screens/environments/colors'
import { ArrowLeftOutlined, ArrowRightOutlined, DownSquareOutlined, MoreOutlined, UnorderedListOutlined } from "@ant-design/icons";
import { keys } from "@mui/system";
import EKey from "../key/key";



class SmsTDL extends Component {

  static getDerivedStateFromProps(nextProps) {
    const { vs, clientActions } = nextProps;
    const keys = vs.getTdlWithPath("groups.0.keys");
    const object = vs.getObject("", "");
    const { usecaseId, rowsNumber, maxPageNumber, rowsColor, selectedObjects, customStyle } = vs;
    const memberActions = vs.getMemberActions();
    console.log(`change sms,   with vs`, { keys })
    return {
      usecaseId,
      object,
      keys,
      memberActions,
      rowsNumber,
      maxPageNumber,
      rowsColor,
      selectedObjects,
      clientActions,
      customStyle,

    };
  }

  constructor(props) {
    super(props);
    this.state = {
      usecaseId: null,
      object: [],
      keys: [],
      memberActions: [],
      rowsNumber: null,
      maxPageNumber: null,
      rowsColor: {},
      selectedObjects: [],

    };
  }

  shouldComponentUpdate(nextProps, nextState) {

    return !Util.isEqual(nextState, this.state);

  }



  // componentDidMount() {
  //   console.log("componentDidMount")

  //   this.backHandler = BackHandler.addEventListener(
  //     'hardwareBackPress',
  //     this.backAction
  //   );
  // }

  // backAction = () => {
  //   console.log("this ###")
  //   // console.log(this)
  //   if (this.props.clientActions[this.props.vs.tdl.tdlId] && "back" in this.props.clientActions[this.props.vs.tdl.tdlId]) {
  //     this.props.clientActions[this.props.vs.tdl.tdlId].back.execution({store}, this.props.vs)
  //   } else if ("back" in this.props.clientActions) {
  //     this.props.clientActions.back.execution({store}, this.props.vs)
  //   } else {
  //     this.props.dispatch(requestBack(this.props.usecaseId));
  //   }
  //   return true


  // };
  // componentWillUnmount() {
  //   console.log("componentWillUnmount")
  //   this.backHandler.remove();
  // }


  render() {

    const { dispatch, vs, isRTL, themeName, onSuccessCallbacks, clientActions, customStyle, meta } = this.props;
    const { maxPageNumber, usecaseId, object, memberActions, detailsModalOpen, detailsPath } = this.state;
    this.options = null;
    const theme = getTheme(themeName);
    const locale = {
      prevText: getTranslation("back", isRTL),
      nextText: getTranslation("next", isRTL),
    };
    const isRTLWEB = Platform.OS == "web" ? document.getElementsByTagName('html')[0].dir : "rtl";

    console.log("theme", theme)



    const backButton = (
      <Button
        transparent
        style={{ ...theme.header }}
        onPress={() => {
          this.setState({ detailsModalOpen: false });

        }}

      >
        {Platform.OS != "web" &&
          <Icon as={Ionicons} name={isRTL ? "arrow-back" : "arrow-forward"}
            style={{ ...theme.headerIcon }} />
        }
        {Platform.OS == "web" &&
          <>

            {isRTL ? <ArrowLeftOutlined style={{ ...theme.headerIcon }} /> : <ArrowRightOutlined style={{ ...theme.headerIcon }} />}
          </>
        }
      </Button>
    );


    let allActions = memberActions.map((action) => {
      // console.log({ action })
      const callback = (obj) => {
        if (onSuccessCallbacks && onSuccessCallbacks[action.tdlId]) {
          // console.log("IN CALLBACK")
          // console.log(store)
          onSuccessCallbacks[action.tdlId]({ ...obj, store });

        }

      };
      return <Button

        key={Util.getActionKey(action)}
        onPress={() => {
          dispatch(executeAction(usecaseId, action.tdlId, action.responseType, callback));
          if (this.RBSheet) {
            this.RBSheet.close();
          }
        }}
      >
        {action.actionLabel}
      </Button>
    })


    if (vs && clientActions[vs.tdl.tdlId]) {
      allActions.push(
        Object.entries(clientActions[vs.tdl.tdlId]).map((action) => {
          action = action[1];
          return (
            action.position === "member" && (
              <Button
                key={action.actionName}
                onPress={() => {
                  action.execution({ store, vs });
                  if (this.RBSheet) {
                    this.RBSheet.close();
                  }
                }}
              >
                {action.actionName}
              </Button>
            )
          );
        }),
        // ),
      );
    }
    const menuActions = (
      <ScrollView>
        {(allActions.length > 0 &&
          allActions) || <Text >{getTranslation("noOperations")}</Text>}
      </ScrollView>
    );

    const smsContent = (object, item, index) => {
      return <>
        <Pressable
          onPress={(e) => {
            console.log("rrriight", e)
            this.setState({ detailsModalOpen: true, detailsPath: object && object.indexOf(item) });
          }}
          onLongPress={() => {
            dispatch(setCurrentObjectPath(usecaseId, item.pk));
            dispatch(sendRefreshRequest(usecaseId, true, () => { this.RBSheet.open() }))
            // if (this.RBSheet) {
            //   this.RBSheet.open();
            // }
          }}
          style={({ pressed }) => [
            {
              backgroundColor: pressed ? theme.colors.borderColor : "white",
              padding: theme.tdlPressed.padding

            },
          ]}
        >

          <Group
            key={object && index && index.toString()}
            vs={vs}
            path={object && index.toString()}
            tdlPath="groups-0"
            dispatch={dispatch}
            isRTL={isRTL}
            isSMSRow={true}
            smsRowColor={
              object.indexOf(item) % 2 === 0 ? theme.colors.background : theme.colors.faddedBackground
            }
            theme={theme}
            customStyle={customStyle}
            smsAdvance={false}
          />
        </Pressable>
      </>
    }

    return (
      <>

        <View style={{ flex: theme.tdlViewSMS.flex }}>

          {/* <KeyboardAwareScrollView> */}
          <ScrollView >
            {object &&
              object.map((item, index) => (
                <>
                  {Platform.OS != "web" &&
                    <View style={theme.tdlViewSMSMobile}>
                      {smsContent(object, item, index)}
                    </View>
                  }
                  {Platform.OS == "web" &&

                    <View style={theme.tdlViewSMSWEB}>
                      <View style={theme.tdlSMSContainer}>
                        <View style={theme.tdlSMSIconContainer}>
                          <MoreOutlined
                            style={theme.tdlSMSIcon}
                            onClick={() => {
                              dispatch(setCurrentObjectPath(usecaseId, item.pk));
                              dispatch(sendRefreshRequest(usecaseId, true, () => { this.RBSheet.open() }))
                              // if (this.RBSheet) {
                            }}
                          />
                        </View>
                        {smsContent(object, item, index)}
                      </View>
                    </View>
                  }
                </>
              ))}
          </ScrollView>
          {/* </KeyboardAwareScrollView> */}

          <View
            style={
              {
                // flex:2
                // ...theme.pagination,
                // flexDirection: "row",
                // position: "absolute",
                // bottom: 0,

              }
            }
          >
            <Pagination
              onChange={(index) => {
                dispatch(SMSPagination(usecaseId, index - 1));
              }}
              total={(object.length < vs.rowsNumber && maxPageNumber) || 100000}
              current={maxPageNumber}
              simple={true}
              locale={locale}
            // style={{backgroundColor:"pink"}}
            />
          </View>

          <RBSheet
            ref={(ref) => {
              this.RBSheet = ref;
            }}
            openDuration={250}
          >
            {menuActions}
          </RBSheet>

          <Modal animationType={"slide"} visible={detailsModalOpen === true}
            style={{ flex: 1 }}>
            <VStack space={3} divider={<Divider />} w="100%" >
              <HStack style={[theme.headerModal, theme.tdlHStackSMS]}>

                <Text style={theme.headerModalTitle}>{getTranslation("details")}</Text>
                {backButton}

              </HStack>
            </VStack>
            <>
              <ScrollView
                style={theme.tdlScrollView}
              >
                <Group
                  key={detailsPath}
                  vs={vs}
                  path={detailsPath}
                  tdlPath="groups-0"
                  dispatch={dispatch}
                  isRTL={isRTL}
                  theme={theme}
                  customStyle={customStyle}
                  smsAdvance={true}
                />
              </ScrollView>
            </>
          </Modal>
        </View>
      </>
    );
  }
}

SmsTDL.propTypes = {
  vs: PropTypes.objectOf(PropTypes.any).isRequired,
  dispatch: PropTypes.func.isRequired,
  isRTL: PropTypes.bool.isRequired,
  themeName: PropTypes.string.isRequired,
  onSuccessCallbacks: PropTypes.objectOf(PropTypes.any).isRequired,
  clientActions: PropTypes.objectOf(PropTypes.any),
  customStyle: PropTypes.objectOf(PropTypes.any)
};

export default SmsTDL;

==> elixir-react-native-components-1.2.2-6.tgz: package/components/tdl/sms.js <==
import React, { Component } from "react";
import PropTypes from "prop-types";
import { ScrollView, View, Pressable, Text, Modal, StatusBar, BackHandler, Platform } from "react-native";
import { Icon, HStack, Left, Body, Title, Right, VStack, Divider } from "native-base";
import { Ionicons } from '@expo/vector-icons';
import RBSheet from "react-native-raw-bottom-sheet";
import { KeyboardAwareScrollView } from "react-native-keyboard-aware-scrollview";
import { Button, Pagination } from "@ant-design/react-native";
import * as Util from "../../helpers/util";
import Group from "../group/index";
import { SMSPagination, setCurrentObjectPath, executeAction, sendRefreshRequest, requestBack } from "../../redux/actions";
import { getTranslation } from "../../labels";
import { getTheme } from "../../styles/themes";
import store from "@muhammadz/elixir-react-stateful/redux";
import * as colors from './../../src-screens/environments/colors'
import { ArrowLeftOutlined, ArrowRightOutlined, DownSquareOutlined, MoreOutlined, UnorderedListOutlined } from "@ant-design/icons";
import { keys } from "@mui/system";
import EKey from "../key/key";



class SmsTDL extends Component {

  static getDerivedStateFromProps(nextProps) {
    const { vs, clientActions } = nextProps;
    const keys = vs.getTdlWithPath("groups.0.keys");
    const object = vs.getObject("", "");
    const { usecaseId, rowsNumber, maxPageNumber, rowsColor, selectedObjects, customStyle } = vs;
    const memberActions = vs.getMemberActions();
    console.log(`change sms,   with vs`, { keys })
    return {
      usecaseId,
      object,
      keys,
      memberActions,
      rowsNumber,
      maxPageNumber,
      rowsColor,
      selectedObjects,
      clientActions,
      customStyle,

    };
  }

  constructor(props) {
    super(props);
    this.state = {
      usecaseId: null,
      object: [],
      keys: [],
      memberActions: [],
      rowsNumber: null,
      maxPageNumber: null,
      rowsColor: {},
      selectedObjects: [],

    };
  }

  shouldComponentUpdate(nextProps, nextState) {

    return !Util.isEqual(nextState, this.state);

  }



  // componentDidMount() {
  //   console.log("componentDidMount")

  //   this.backHandler = BackHandler.addEventListener(
  //     'hardwareBackPress',
  //     this.backAction
  //   );
  // }

  // backAction = () => {
  //   console.log("this ###")
  //   // console.log(this)
  //   if (this.props.clientActions[this.props.vs.tdl.tdlId] && "back" in this.props.clientActions[this.props.vs.tdl.tdlId]) {
  //     this.props.clientActions[this.props.vs.tdl.tdlId].back.execution({store}, this.props.vs)
  //   } else if ("back" in this.props.clientActions) {
  //     this.props.clientActions.back.execution({store}, this.props.vs)
  //   } else {
  //     this.props.dispatch(requestBack(this.props.usecaseId));
  //   }
  //   return true


  // };
  // componentWillUnmount() {
  //   console.log("componentWillUnmount")
  //   this.backHandler.remove();
  // }


  render() {

    const { dispatch, vs, isRTL, themeName, onSuccessCallbacks, clientActions, customStyle, meta } = this.props;
    const { maxPageNumber, usecaseId, object, memberActions, detailsModalOpen, detailsPath } = this.state;
    this.options = null;
    const theme = getTheme(themeName);
    const locale = {
      prevText: getTranslation("back", isRTL),
      nextText: getTranslation("next", isRTL),
    };
    const isRTLWEB = Platform.OS == "web" ? document.getElementsByTagName('html')[0].dir : "rtl";

    console.log("theme", theme)



    const backButton = (
      <Button
        transparent
        style={{ ...theme.header }}
        onPress={() => {
          this.setState({ detailsModalOpen: false });

        }}

      >
        {Platform.OS != "web" &&
          <Icon as={Ionicons} name={isRTL ? "arrow-back" : "arrow-forward"}
            style={{ ...theme.headerIcon }} />
        }
        {Platform.OS == "web" &&
          <>

            {isRTL ? <ArrowLeftOutlined style={{ ...theme.headerIcon }} /> : <ArrowRightOutlined style={{ ...theme.headerIcon }} />}
          </>
        }
      </Button>
    );


    let allActions = memberActions.map((action) => {
      // console.log({ action })
      const callback = (obj) => {
        if (onSuccessCallbacks && onSuccessCallbacks[action.tdlId]) {
          // console.log("IN CALLBACK")
          // console.log(store)
          onSuccessCallbacks[action.tdlId]({ ...obj, store });

        }

      };
      return <Button

        key={Util.getActionKey(action)}
        onPress={() => {
          dispatch(executeAction(usecaseId, action.tdlId, action.responseType, callback));
          if (this.RBSheet) {
            this.RBSheet.close();
          }
        }}
      >
        {action.actionLabel}
      </Button>
    })


    if (vs && clientActions[vs.tdl.tdlId]) {
      allActions.push(
        Object.entries(clientActions[vs.tdl.tdlId]).map((action) => {
          action = action[1];
          return (
            action.position === "member" && (
              <Button
                key={action.actionName}
                onPress={() => {
                  action.execution({ store, vs });
                  if (this.RBSheet) {
                    this.RBSheet.close();
                  }
                }}
              >
                {action.actionName}
              </Button>
            )
          );
        }),
        // ),
      );
    }
    const menuActions = (
      <ScrollView>
        {(allActions.length > 0 &&
          allActions) || <Text >{getTranslation("noOperations")}</Text>}
      </ScrollView>
    );

    const smsContent = (object, item, index) => {
      return <>
        <Pressable
          onPress={(e) => {
            console.log("rrriight", e)
            this.setState({ detailsModalOpen: true, detailsPath: object && object.indexOf(item) });
          }}
          onLongPress={() => {
            dispatch(setCurrentObjectPath(usecaseId, item.pk));
            dispatch(sendRefreshRequest(usecaseId, true, () => { this.RBSheet.open() }))
            // if (this.RBSheet) {
            //   this.RBSheet.open();
            // }
          }}
          style={({ pressed }) => [
            {
              backgroundColor: pressed ? theme.colors.borderColor : "white",
              padding: theme.tdlPressed.padding

            },
          ]}
        >

          <Group
            key={object && index && index.toString()}
            vs={vs}
            path={object && index.toString()}
            tdlPath="groups-0"
            dispatch={dispatch}
            isRTL={isRTL}
            isSMSRow={true}
            smsRowColor={
              object.indexOf(item) % 2 === 0 ? theme.colors.background : theme.colors.faddedBackground
            }
            theme={theme}
            customStyle={customStyle}
            smsAdvance={false}
          />
        </Pressable>
      </>
    }

    return (
      <>

        <View style={{ flex: theme.tdlViewSMS.flex }}>

          {/* <KeyboardAwareScrollView> */}
          <ScrollView >
            {object &&
              object.map((item, index) => (
                <>
                  {Platform.OS != "web" &&
                    <View style={theme.tdlViewSMSMobile}>
                      {smsContent(object, item, index)}
                    </View>
                  }
                  {Platform.OS == "web" &&

                    <View style={theme.tdlViewSMSWEB}>
                      <View style={theme.tdlSMSContainer}>
                        <View style={theme.tdlSMSIconContainer}>
                          <MoreOutlined
                            style={theme.tdlSMSIcon}
                            onClick={() => {
                              dispatch(setCurrentObjectPath(usecaseId, item.pk));
                              dispatch(sendRefreshRequest(usecaseId, true, () => { this.RBSheet.open() }))
                              // if (this.RBSheet) {
                            }}
                          />
                        </View>
                        {smsContent(object, item, index)}
                      </View>
                    </View>
                  }
                </>
              ))}
          </ScrollView>
          {/* </KeyboardAwareScrollView> */}

          <View
            style={
              {
                // flex:2
                // ...theme.pagination,
                // flexDirection: "row",
                // position: "absolute",
                // bottom: 0,

              }
            }
          >
            <Pagination
              onChange={(index) => {
                dispatch(SMSPagination(usecaseId, index - 1));
              }}
              total={(object.length < vs.rowsNumber && maxPageNumber) || 100000}
              current={maxPageNumber}
              simple={true}
              locale={locale}
            // style={{backgroundColor:"pink"}}
            />
          </View>

          <RBSheet
            ref={(ref) => {
              this.RBSheet = ref;
            }}
            openDuration={250}
          >
            {menuActions}
          </RBSheet>

          <Modal animationType={"slide"} visible={detailsModalOpen === true}
            style={{ flex: 1 }}>
            <VStack space={3} divider={<Divider />} w="100%" >
              <HStack style={[theme.headerModal, theme.tdlHStackSMS]}>

                <Text style={theme.headerModalTitle}>{getTranslation("details")}</Text>
                {backButton}

              </HStack>
            </VStack>
            <>
              <ScrollView
                style={theme.tdlScrollView}
              >
                <Group
                  key={detailsPath}
                  vs={vs}
                  path={detailsPath}
                  tdlPath="groups-0"
                  dispatch={dispatch}
                  isRTL={isRTL}
                  theme={theme}
                  customStyle={customStyle}
                  smsAdvance={true}
                />
              </ScrollView>
            </>
          </Modal>
        </View>
      </>
    );
  }
}

SmsTDL.propTypes = {
  vs: PropTypes.objectOf(PropTypes.any).isRequired,
  dispatch: PropTypes.func.isRequired,
  isRTL: PropTypes.bool.isRequired,
  themeName: PropTypes.string.isRequired,
  onSuccessCallbacks: PropTypes.objectOf(PropTypes.any).isRequired,
  clientActions: PropTypes.objectOf(PropTypes.any),
  customStyle: PropTypes.objectOf(PropTypes.any)
};

export default SmsTDL;
